==> nextalarm_0.2.4-1.tar.gz: nextalarm-0.2.4/src/nextalarm_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="59"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished">Alarmas en las siguientes %1 h</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="166"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished">Opciones de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="32"/>
        <source>Lines</source>
        <translation type="unfinished">Líneas</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="52"/>
        <source>Width</source>
        <translation type="unfinished">Ancho</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>Font</source>
        <translation type="unfinished">Fuente</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="109"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="127"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="134"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="141"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Size</source>
        <translation type="unfinished">Tamaño</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="180"/>
        <source>Only std Alarms</source>
        <translation type="unfinished">Sólo Alarmas std</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="187"/>
        <source>TimeRemain</source>
        <translation type="unfinished">Tiempo restante</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="194"/>
        <source>Header</source>
        <translation type="unfinished">Encabezado</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="201"/>
        <source>Alarm Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="214"/>
        <source>About</source>
        <translation type="unfinished">Acerca de...</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="221"/>
        <source>About Qt</source>
        <translation type="unfinished">Acerca de Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="102"/>
        <source>About Next Alarm</source>
        <translation type="unfinished">Acerca de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="103"/>
        <source>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing time of next alarm</source>
        <translation type="unfinished">&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Usa &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget de escritorio, que muestra la hora de siguiente alarma</translation>
    </message>
</context>
</TS>

==> nextalarm_0.2.9.tar.gz: nextalarm-0.2.9/src/nextalarm_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="59"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished">Alarmas en las siguientes %1 h</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="166"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished">Opciones de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="32"/>
        <source>Lines</source>
        <translation type="unfinished">Líneas</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="52"/>
        <source>Width</source>
        <translation type="unfinished">Ancho</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>Font</source>
        <translation type="unfinished">Fuente</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="109"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="127"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="134"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="141"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Size</source>
        <translation type="unfinished">Tamaño</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="180"/>
        <source>Only std Alarms</source>
        <translation type="unfinished">Sólo Alarmas std</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="368"/>
        <source>Show Time Remain</source>
        <translation type="unfinished">Tiempo restante</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="194"/>
        <source>Header</source>
        <translation type="unfinished">Encabezado</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="201"/>
        <source>Alarm Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="214"/>
        <source>About</source>
        <translation type="unfinished">Acerca de...</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="221"/>
        <source>About Qt</source>
        <translation type="unfinished">Acerca de Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="102"/>
        <source>About Next Alarm</source>
        <translation type="unfinished">Acerca de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="103"/>
        <source>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing time of next alarm</source>
        <translation type="unfinished">&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Usa &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget de escritorio, que muestra la hora de siguiente alarma</translation>
    </message>
</context>
</TS>
